<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: 404.php,v 1.21 2004/09/23 14:53:40 yeupou Exp $
//
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


require "./include/pre.php";
require_directory("search");

site_header(array('title'=>_("Requested Page not Found (Error 404)")));


print '<p class="warn">'.sprintf(_("The web page you are trying to access doesn't exist on %s."), $GLOBALS['sys_name']).'</p>';
print '<p>'.sprintf(_("If you think that there's a broken link on %s that must be repaired, %s, mentioning the url your tried to access (%s)."), $GLOBALS['sys_name'], utils_link($GLOBALS['sys_home'].'support/?group='.$GLOBALS['sys_unix_group_name'],_("fill a support request")) , $_SERVER['REQUEST_URI']).'</p>';

print '<p>'.sprintf(_("Otherwise, you can return to the %s %s."), $GLOBALS['sys_name'], utils_link($GLOBALS['sys_home'], _("main page"))).'</p>';


$HTML->footer(array());

?>
